Dir[File.dirname(__FILE__) + '/art/**/*.rb'].each do |file|
  load file
end

class Bukkit

  # Represents the art on a painting
  class Art

    attr_reader :id, :width, :height
    BY_NAME = {}
    BY_ID = {}

    def initialize(id, width, height)
      @id = id
      @width = width
      @height = height

      self
    end

    # Gets the width of the painting, in blocks
    #
    # @return [Integer] The width of the painting, in blocks
    def width
      @width
    end
    alias_method :getBlockWidth, :width

    # Gets the height of the painting, in blocks
    #
    # @return [Integer] The height of the painting, in blocks
    def height
      @height
    end
    alias_method :getBlockHeight, :height

    class << self
      def values
        [
          Bukkit::Art::Kebab,
          Bukkit::Art::Aztec,
          Bukkit::Art::Alban,
          Bukkit::Art::Aztec2,
          Bukkit::Art::Bomb,
          Bukkit::Art::Plant,
          Bukkit::Art::Wasteland,
          Bukkit::Art::Pool,
          Bukkit::Art::Courbet,
          Bukkit::Art::Sea,
          Bukkit::Art::Sunset,
          Bukkit::Art::Creebet,
          Bukkit::Art::Wanderer,
          Bukkit::Art::Graham,
          Bukkit::Art::Match,
          Bukkit::Art::Bust,
          Bukkit::Art::Stage,
          Bukkit::Art::Void,
          Bukkit::Art::SkullAndRoses,
          Bukkit::Art::Wither,
          Bukkit::Art::Fighters,
          Bukkit::Art::Pointer,
          Bukkit::Art::Pigscene,
          Bukkit::Art::Burningskull,
          Bukkit::Art::Skeleton,
          Bukkit::Art::Donkeykong
        ]
      end

      def by_name(name)
        if name
          name = name.to_s unless name.is_a? String
          BY_NAME[name.downcase]
        end
      end
      alias_method :getByName, :by_name
    end
    
    begin
      values.each do |art|
        BY_ID[art.new.id] = art
        BY_NAME[art.to_s.split('::').last.downcase] = art
      end
    end

  end

end
