class Bukkit

  module BanList

    module Type

      # Banned player names
      NAME = []

      # Banned player IP addresses
      IP = []

    end

    # Gets a {Bukkit::BanEntry} by target.
    #
    # @param target [String] entry parameter to search for
    # @return [Bukkit::BanEntry] the corresponding entry, or null if none found
    def ban_entry(target); end
    alias_method :getBanEntry, :ban_entry

    # Adds a ban to this list. If a previous ban exists, this will
    # update the previous entry.
    #
    # @param target [String] the target of the ban
    # @param reason [String] reason for the ban, nil indicates implementation default
    # @param expires [Date] date for the ban's expiration (unban), or nil to imply
    #   forever
    # @param source [String] source of the ban, nil indicates implementation default
    # @return [Bukkit::BanEntry] the entry for the newly created ban, or the entry for the
    #   (updated) previous ban
    def ban(target, reason, expires, source); end
    alias_method :addBan, :ban

    # Gets a set containing every {Bukkit::BanEntry} in this list.
    #
    # @return [Array] an array containing every entry tracked by this list
    def ban_entries; end
    alias_method :getBanEntries, :ban_entries

    # Gets if a {Bukkit::BanEntry} exists for the target, indicating an active
    # ban status.
    #
    # @param target [String] the target to find
    # @return [boolean] true if a {Bukkit::BanEntry} exists for the name, indicating
    #   an active ban status, false otherwise
    def banned?(target); end
    alias_method :isBanned, :banned?

    # Removes the specified target from this list, therefore indicating a
    #   "not banned" status/
    #
    # @param target [String] the target to remove from this list
    def pardon(target); end

  end

end